@@ -19,6 +19,8 @@
 
 package demo.wssec.client;
 
+import java.io.Closeable;
+
 import java.lang.reflect.UndeclaredThrowableException;
 import java.net.URL;
 import java.util.HashMap;
@@ -30,7 +32,6 @@ import org.apache.cxf.bus.spring.SpringBusFactory;
 import org.apache.cxf.hello_world_soap_http.Greeter;
 import org.apache.cxf.hello_world_soap_http.GreeterService;
 
-import org.apache.cxf.ws.security.wss4j.DefaultCryptoCoverageChecker;
 import org.apache.cxf.ws.security.wss4j.WSS4JInInterceptor;
 import org.apache.cxf.ws.security.wss4j.WSS4JOutInterceptor;
 
@@ -56,9 +57,12 @@ public final class Client {
             outProps.put("action", "UsernameToken Timestamp Signature Encrypt");
 
             outProps.put("passwordType", "PasswordDigest");
+            outProps.put("user", "clientx509v1");
 
-            outProps.put("user", "abcd");
-            outProps.put("signatureUser", "clientx509v1");
+            //If you are using the patch WSS-194, then uncomment below two lines and 
+            //comment the above "user" prop line.
+            //outProps.put("user", "abcd");
+            //outProps.put("signatureUser", "clientx509v1");
 
             outProps.put("passwordCallbackClass", "demo.wssec.client.UTPasswordCallback");
 
@@ -91,14 +95,6 @@ public final class Client {
 
             bus.getInInterceptors().add(new WSS4JInInterceptor(inProps));
 
-            // Check to make sure that the SOAP Body and Timestamp were signed,
-            // and that the SOAP Body was encrypted
-            DefaultCryptoCoverageChecker coverageChecker = new DefaultCryptoCoverageChecker();
-            coverageChecker.setSignBody(true);
-            coverageChecker.setSignTimestamp(true);
-            coverageChecker.setEncryptBody(true);
-            bus.getInInterceptors().add(coverageChecker);
-
             GreeterService service = new GreeterService();
             Greeter port = service.getGreeterPort();
 
@@ -110,9 +106,13 @@ public final class Client {
                 System.out.println("response: " + response + "\n");
             }
 
-            // allow asynchronous resends to occur
+            // allow aynchronous resends to occur
             Thread.sleep(30 * 1000);
 
+            if (port instanceof Closeable) {
+                ((Closeable)port).close();
+            }
+
             bus.shutdown(true);
 
         } catch (UndeclaredThrowableException ex) {
